@@ -498,11 +498,11 @@ void ShortcutMapper::resizeDialogElements()
 {
 	constexpr auto getRcWidth = [](const RECT& rc) -> int {
 		return rc.right - rc.left;
-		};
+	};
 
 	constexpr auto getRcHeight = [](const RECT& rc) -> int {
 		return rc.bottom - rc.top;
-		};
+	};
 
 	auto setOrDeferWindowPos = [](HDWP hWinPosInfo, HWND hWnd, HWND hWndInsertAfter, int x, int y, int cx, int cy, UINT uFlags) -> HDWP {
 		if (hWinPosInfo != nullptr)
@@ -511,7 +511,7 @@ void ShortcutMapper::resizeDialogElements()
 		}
 		::SetWindowPos(hWnd, hWndInsertAfter, x, y, cx, cy, uFlags);
 		return nullptr;
-		};
+	};
 
 	constexpr UINT flags = SWP_NOZORDER | SWP_NOOWNERZORDER | SWP_NOACTIVATE | SWP_NOCOPYBITS;
 
@@ -543,6 +543,13 @@ void ShortcutMapper::resizeDialogElements()
 	::GetWindowRect(hFilterEdit, &rcFilterEdit);
 	::MapWindowPoints(nullptr, _hSelf, reinterpret_cast<LPPOINT>(&rcFilterEdit), 2);
 
+	RECT rcFilterClearBtn{};
+	HWND hFilterClearBtn = ::GetDlgItem(_hSelf, IDC_BABYGRID_FILTER_CLEAR);
+	::GetWindowRect(hFilterClearBtn, &rcFilterClearBtn);
+
+	int clrBtnWidth = rcFilterClearBtn.right - rcFilterClearBtn.left;
+	int clrBtnHeight = rcFilterClearBtn.bottom - rcFilterClearBtn.top;
+
 	RECT rcInfo{};
 	HWND hInfo = ::GetDlgItem(_hSelf, IDC_BABYGRID_INFO);
 	::GetWindowRect(hInfo, &rcInfo);
@@ -562,7 +569,7 @@ void ShortcutMapper::resizeDialogElements()
 	const int heightFilter = getRcHeight(rcFilterEdit);
 	const int heightInfo = getRcHeight(rcInfo);
 
-	constexpr int nCtrls = 7;
+	constexpr int nCtrls = 8;
 	auto hdwp = ::BeginDeferWindowPos(nCtrls);
 
 	hdwp = setOrDeferWindowPos(hdwp, hModBtn, nullptr, center - gapBtnHalf - wBtn * 2 - gapBtn, rcClient.bottom, 0, 0, SWP_NOSIZE | flags);
@@ -572,7 +579,8 @@ void ShortcutMapper::resizeDialogElements()
 
 	rcClient.bottom -= (gapBtnEdit + heightFilter);
 	hdwp = setOrDeferWindowPos(hdwp, hStatic, nullptr, rcClient.left, rcClient.bottom + gapBtnEdit / 2, 0, 0, SWP_NOSIZE | flags);
-	hdwp = setOrDeferWindowPos(hdwp, hFilterEdit, nullptr, rcFilterEdit.left, rcClient.bottom, rcClient.right - rcFilterEdit.left, heightFilter, flags);
+	hdwp = setOrDeferWindowPos(hdwp, hFilterEdit, nullptr, rcFilterEdit.left, rcClient.bottom, rcClient.right - rcFilterEdit.left - clrBtnWidth, heightFilter, flags);
+	hdwp = setOrDeferWindowPos(hdwp, hFilterClearBtn, nullptr, rcClient.right - clrBtnWidth + 2, rcClient.bottom, clrBtnWidth, clrBtnHeight, SWP_NOSIZE | flags);
 	hdwp = setOrDeferWindowPos(hdwp, hInfo, nullptr, rcClient.left, rcClient.bottom - gapBtnEdit - heightInfo, getRcWidth(rcClient), heightInfo, flags);
 
 	if (hdwp)
@@ -1360,7 +1368,13 @@ intptr_t CALLBACK ShortcutMapper::run_dlgProc(UINT message, WPARAM wParam, LPARA
 					}
 					return TRUE;
 				}
-
+				case IDC_BABYGRID_FILTER_CLEAR:
+				{
+					HWND hFilterEdit = ::GetDlgItem(_hSelf, IDC_BABYGRID_FILTER);
+					::SetWindowText(hFilterEdit, L"");
+					::SetFocus(hFilterEdit);
+					return TRUE;
+				}
 				default:
 				{
 					break;
